==> deepin-font-installer_1.0.4.orig.tar.xz: deepin-font-installer-1.0.4/deepin-font-installer/translations/deepin-font-installer_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>HomePage</name>
    <message>
        <source>Drag font file here</source>
        <translation>Přetáhněte soubor písem zde</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>Zvolte soubor</translation>
    </message>
</context>
<context>
    <name>ListItem</name>
    <message>
        <source>Installed</source>
        <translation>Nainstalován</translation>
    </message>
    <message>
        <source>Other version installed: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Installing</source>
        <translation>Instalace</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Deepin Font Installer</source>
        <translation>Deepin Font Installer</translation>
    </message>
    <message>
        <source>Deepin Font Installer is used to install and uninstall font file for users with bulk install function.</source>
        <translation>Deepin Font Installer se používá k instalaci a odinstalování souboru písem pro uživatele s hromadnou instalací.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Deepin Font Installer</source>
        <translation>Deepin Font Installer</translation>
    </message>
    <message>
        <source>Bulk Install</source>
        <translation>Hromadná instalace</translation>
    </message>
</context>
<context>
    <name>MultiFilePage</name>
    <message>
        <source>Install</source>
        <translation>Nainstalujte</translation>
    </message>
    <message>
        <source>Installed successfully</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>View font directory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Refreshing font cache, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SingleFilePage</name>
    <message>
        <source>Install</source>
        <translation>Nainstalovat</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Reinstalace</translation>
    </message>
    <message>
        <source>View font directory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Style: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Type: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copyright: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Description: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Same version installed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Installed successfully</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Removed successfully</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Other version installed: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Done</source>
        <translation>Hotovo</translation>
    </message>
</context>
</TS>

==> deepin-font-installer_1.1.orig.tar.xz: deepin-font-installer-1.1/deepin-font-installer/translations/deepin-font-installer_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>HomePage</name>
    <message>
        <source>Drag font file here</source>
        <translation>Přetáhněte soubor písem zde</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>Vybrat soubor</translation>
    </message>
</context>
<context>
    <name>ListItem</name>
    <message>
        <source>Installed</source>
        <translation>Nainstalováno</translation>
    </message>
    <message>
        <source>Other version installed: %1</source>
        <translation>Je nainstalována jiná verze: %1</translation>
    </message>
    <message>
        <source>Installing</source>
        <translation>Instalace</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Stejná verze je již nainstalována</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Deepin Font Installer</source>
        <translation>Instalátor písem</translation>
    </message>
    <message>
        <source>Deepin Font Installer is used to install and uninstall font file for users with bulk install function.</source>
        <translation>Instalátor písem Deepinu se používá k nainstalování a odinstalování souborů s písmy pro uživatele s hromadnou instalací.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Deepin Font Installer</source>
        <translation>Instalátor písem</translation>
    </message>
    <message>
        <source>Bulk Install</source>
        <translation>Hromadná instalace</translation>
    </message>
</context>
<context>
    <name>MultiFilePage</name>
    <message>
        <source>Install</source>
        <translation>Instalovat</translation>
    </message>
    <message>
        <source>Installed successfully</source>
        <translation>Nainstalováno úspěšně</translation>
    </message>
    <message>
        <source>View font directory</source>
        <translation>Zobrazit adresář s písmy</translation>
    </message>
    <message>
        <source>Refreshing font cache, please wait...</source>
        <translation>Obnovuje se vyrovnávací paměť písem, počkejte, prosím...</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Neznámý</translation>
    </message>
</context>
<context>
    <name>SingleFilePage</name>
    <message>
        <source>Install</source>
        <translation>Instalovat</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Reinstalovat</translation>
    </message>
    <message>
        <source>View font directory</source>
        <translation>Zobrazit adresář s písmy</translation>
    </message>
    <message>
        <source>Style: </source>
        <translation>Styl: </translation>
    </message>
    <message>
        <source>Type: </source>
        <translation>Typ: </translation>
    </message>
    <message>
        <source>Version: </source>
        <translation>Verze:</translation>
    </message>
    <message>
        <source>Copyright: </source>
        <translation>Autorské právo:</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Popis:</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Stejná verze je již nainstalována</translation>
    </message>
    <message>
        <source>Installed successfully</source>
        <translation>Nainstalováno úspěšně</translation>
    </message>
    <message>
        <source>Removed successfully</source>
        <translation>Odstraněno úspěšně</translation>
    </message>
    <message>
        <source>Other version installed: %1</source>
        <translation>Je nainstalována jiná verze: %1</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Hotovo</translation>
    </message>
</context>
</TS>
